@@ -114,6 +114,9 @@ void ActivityWidget::updateText() {
   if (!generatorName.isEmpty() && (verb != "share"))
     text += QString(tr(" via %1")).arg(generatorName);
 
+  if (verb == "share")
+    text = QString::fromUtf8("\342\231\273") + " " + text;
+
   if (verb == "post") {
     QString toStr = recipientsToString(m_activity->to());
     QString ccStr = recipientsToString(m_activity->cc());
