@@ -110,7 +110,7 @@ FullObjectWidget::FullObjectWidget(QASObject* obj, QWidget* parent,
   connect(m_editButton, SIGNAL(clicked()), this, SLOT(onEditClicked()));
   m_buttonLayout->addWidget(m_editButton, 0, Qt::AlignTop);
 
-  m_commentButton = new TextToolButton(tr("comment"), this);
+  m_commentButton = new TextToolButton(tr("comment", "Button to comment on a post"), this);
   connect(m_commentButton, SIGNAL(clicked()), this, SLOT(reply()));
   m_buttonLayout->addWidget(m_commentButton, 0, Qt::AlignTop);
 
@@ -346,7 +346,7 @@ void FullObjectWidget::updateInfoText() {
     
     QString location = m_actor->location();
     if (!location.isEmpty())
-      infoStr += " " + QString(tr("at %1")).arg(location);
+      infoStr += " " + QString(tr("at %1", "location of person")).arg(location);
     if (m_actor->updatedDate().isValid())
       infoStr += ".<br/>" + QString(tr("Profile last updated %1")).
 	arg(relativeFuzzyTime(m_actor->updatedDate(), true));
@@ -363,7 +363,7 @@ void FullObjectWidget::updateInfoText() {
     if (author)
       infoStr = QString("<a href=\"%2\">%1</a>").
         arg(author->displayName()).
-        arg(author->url()) + " " + QString(tr("at %1")).arg(infoStr);
+        arg(author->url()) + " " + QString(tr("at %1", "time when post was published")).arg(infoStr);
 
     QASLocation* loc = m_object->location();
     if (!loc->isEmpty()) {
@@ -414,7 +414,7 @@ void FullObjectWidget::updateFollowButton(bool /*wait*/) {
   if (!m_followButton)
     return;
   
-  if (!isFollowable(m_object)) {
+  if (!isFollowable(m_object) || !m_actor->followedKnown()) {
     m_followButton->setVisible(false);
     return;
   }
@@ -429,9 +429,11 @@ void FullObjectWidget::updateFollowButton(bool /*wait*/) {
 void FullObjectWidget::updateFollowAuthorButton(bool /*wait*/) {
   if (!m_followAuthorButton)
     return;
-  
-  if (!m_author || !isFollowable(m_author) || m_author->followed()) {
-    m_followAuthorButton->setVisible(false);
+
+   if (!m_author || !isFollowable(m_author) || m_author->followed() ||
+      !m_author->followedKnown()) {
+
+     m_followAuthorButton->setVisible(false);
     return;
   }
 
@@ -541,7 +543,10 @@ void FullObjectWidget::updateShares() {
     int others = ns-m_object->shares()->size();
     if (others >= 1)
       text += QString(" ") + tr("and %Ln other person(s)", 0, others);
-    text += QString(" ") + tr("shared this.");
+    if (ns > 1)
+      text += QString(" ") + tr("shared this.", "Many persons shared");
+    else 
+      text += QString(" ") + tr("shared this.", "One person shared");
   } else {
     if (ns >= 1)
       text = tr("%Ln person(s) shared this.", 0, ns);
@@ -665,14 +670,14 @@ void FullObjectWidget::reply() {
 //------------------------------------------------------------------------------
 
 QString FullObjectWidget::typeName() const {
-  QString typeName = tr("post");
+  QString typeName = tr("post", "Name of object type.");
   QString tn = m_object->type();
   if (tn == "note")
-    typeName = tr("note");
+    typeName = tr("note", "Name of object type.");
   else if (tn == "comment")
-    typeName = tr("comment");
+    typeName = tr("comment", "Name of object type.");
   else if (tn == "image")
-    typeName = tr("image");
+    typeName = tr("image", "Name of object type.");
 
   return typeName;
 }
