@@ -30,6 +30,7 @@
 #include "util.h"
 #include "filedownloader.h"
 #include "qaspell.h"
+#include "editprofiledialog.h"
 
 //------------------------------------------------------------------------------
 
@@ -40,6 +41,7 @@ PumpApp::PumpApp(PumpaSettings* settings, QString locale, QWidget* parent) :
   m_isLoading(false),
   m_wiz(NULL),
   m_messageWindow(NULL),
+  m_editProfileDialog(NULL),
   m_trayIcon(NULL),
   m_locale(locale),
   m_uploadDialog(NULL),
@@ -306,11 +308,7 @@ void PumpApp::startPumping() {
 
   m_recipientLists.clear();
 
-  QVariantMap publicJson;
-  publicJson["displayName"] = tr("Public");
-  publicJson["objectType"] = "collection";
-  publicJson["id"] = PUBLIC_RECIPIENT_ID;
-  m_recipientLists.append(QASObject::getObject(publicJson, this));
+  addPublicRecipient(m_recipientLists);
 
   QVariantMap followersJson;
   followersJson["displayName"] = tr("Followers");
@@ -318,7 +316,7 @@ void PumpApp::startPumping() {
   followersJson["id"] = apiUrl(apiUser("followers"));
   m_recipientLists.append(QASObject::getObject(followersJson, this));
 
-  request(apiUser(""), QAS_SELF_PROFILE);
+  request(apiUser("profile"), QAS_SELF_PROFILE);
   request(apiUser("lists/person"), QAS_SELF_LISTS);
   fetchAll(true);
 
@@ -672,6 +670,9 @@ void PumpApp::createActions() {
   followAction->setShortcut(tr("Ctrl+L"));
   connect(followAction, SIGNAL(triggered()), this, SLOT(followDialog()));
 
+  profileAction = new QAction(tr("Your &profile"), this);
+  connect(profileAction, SIGNAL(triggered()), this, SLOT(editProfile()));
+
   aboutAction = new QAction(tr("&About"), this);
   connect(aboutAction, SIGNAL(triggered()), this, SLOT(about()));
 
@@ -690,7 +691,7 @@ void PumpApp::createActions() {
   connect(m_debugAction, SIGNAL(triggered()), this, SLOT(debugAction()));
   addAction(m_debugAction);
   
-  m_closeTabAction = new QAction("Close tab", this);
+  m_closeTabAction = new QAction(tr("Close tab"), this);
   m_closeTabAction->setShortcut(tr("Ctrl+W"));
   connect(m_closeTabAction, SIGNAL(triggered()), this, SLOT(closeTab()));
   m_closeTabAction->setEnabled(false);
@@ -723,6 +724,7 @@ void PumpApp::createMenu() {
   fileMenu->addAction(newNoteAction);
   fileMenu->addSeparator();
   fileMenu->addAction(followAction);
+  fileMenu->addAction(profileAction);
   fileMenu->addAction(reloadAction);
   fileMenu->addAction(loadOlderAction);
   fileMenu->addSeparator();
@@ -824,6 +826,16 @@ void PumpApp::reportBug() {
 
 //------------------------------------------------------------------------------
 
+void PumpApp::addPublicRecipient(RecipientList& rl) {
+  QVariantMap publicJson;
+  publicJson["displayName"] = tr("Public");
+  publicJson["objectType"] = "collection";
+  publicJson["id"] = PUBLIC_RECIPIENT_ID;
+  rl.append(QASObject::getObject(publicJson, this));
+}
+
+//------------------------------------------------------------------------------
+
 void PumpApp::newNote(QASObject* obj, QASObjectList* to, QASObjectList* cc,
 		      bool edit) {
   if (!m_messageWindow) {
@@ -995,6 +1007,52 @@ void PumpApp::followDialog() {
 
 //------------------------------------------------------------------------------
 
+void PumpApp::editProfile() {
+  request(apiUser("profile"), QAS_EDIT_PROFILE);
+}
+
+//------------------------------------------------------------------------------
+
+void PumpApp::editProfileDialog() {
+  if (!m_editProfileDialog) {
+    m_editProfileDialog = new EditProfileDialog(this);
+    connect(m_editProfileDialog, SIGNAL(profileEdited(QASActor*, QString)), 
+            this, SLOT(onProfileEdited(QASActor*, QString)));
+  }
+  m_editProfileDialog->setProfile(m_selfActor);
+  m_editProfileDialog->show();
+}
+
+//------------------------------------------------------------------------------
+
+void PumpApp::onProfileEdited(QASActor* profile, QString newImageFile) {
+  m_profile.clear();
+
+  m_profile["objectType"] = "person";
+  m_profile["displayName"] = profile->displayName();
+  m_profile["summary"] = profile->summary();
+  
+  QVariantMap jsonLoc;
+  jsonLoc["objectType"] = "place";
+  jsonLoc["displayName"] = profile->location();
+  m_profile["location"] = jsonLoc;
+
+  if (newImageFile.isEmpty()) {
+    uploadProfile();
+  } else {
+    postAvatarImage(newImageFile);
+  }
+}
+
+//------------------------------------------------------------------------------
+
+void PumpApp::uploadProfile() {
+  request(apiUser("profile"), QAS_SELF_PROFILE | QAS_REFRESH, 
+          KQOAuthRequest::PUT, m_profile);
+}
+
+//------------------------------------------------------------------------------
+
 void PumpApp::testUserAndFollow(QString username, QString server) {
   QString fingerUrl = QString("%1/.well-known/webfinger?resource=%2@%1").
     arg(server).arg(username);
@@ -1186,7 +1244,20 @@ void PumpApp::postImage(QString msg,
 
 //------------------------------------------------------------------------------
 
-void PumpApp::uploadFile(QString filename) {
+void PumpApp::postAvatarImage(QString imageFile) {
+  m_imageObject.clear();
+
+  m_imageTo = RecipientList();
+  m_imageCc = RecipientList();
+
+  addPublicRecipient(m_imageCc);
+
+  uploadFile(imageFile, QAS_AVATAR_UPLOAD);
+}
+
+//------------------------------------------------------------------------------
+
+void PumpApp::uploadFile(QString filename, int flags) {
   QString lcfn = filename.toLower();
   QString mimeType;
   if (lcfn.endsWith(".jpg") || lcfn.endsWith(".jpeg"))
@@ -1225,14 +1296,15 @@ void PumpApp::uploadFile(QString filename) {
   m_uploadDialog->setValue(0);
   m_uploadDialog->show();
 
-  m_uploadRequest = executeRequest(oaRequest, QAS_IMAGE_UPLOAD);
+  flags = QAS_IMAGE_UPLOAD | flags;
+  m_uploadRequest = executeRequest(oaRequest, flags);
   connect(m_uploadRequest, SIGNAL(uploadProgress(qint64, qint64)),
           this, SLOT(uploadProgress(qint64, qint64)));
 }
 
 //------------------------------------------------------------------------------
 
-void PumpApp::updatePostedImage(QVariantMap obj) {
+void PumpApp::updatePostedImage(QVariantMap obj, int flags) {
   m_imageObject.unite(obj);
 
   // Work-around for https://github.com/e14n/pump.io/issues/885
@@ -1240,14 +1312,18 @@ void PumpApp::updatePostedImage(QVariantMap obj) {
   RecipientList to;
   to.append(m_selfActor);
 
-  feed("update", m_imageObject, QAS_IMAGE_UPDATE, to);
+  feed("update", m_imageObject, QAS_IMAGE_UPDATE | flags, to);
 }
 
 //------------------------------------------------------------------------------
 
-void PumpApp::postImageActivity(QVariantMap) {
-  feed("post", m_imageObject, QAS_ACTIVITY | QAS_REFRESH | QAS_POST,
-       m_imageTo, m_imageCc);
+void PumpApp::postImageActivity(QVariantMap, int flags) {
+  if (flags == 0)
+    flags = QAS_REFRESH;
+
+  flags |= QAS_ACTIVITY | QAS_POST;
+  
+  feed("post", m_imageObject, flags, m_imageTo, m_imageCc);
 }
 
 //------------------------------------------------------------------------------
@@ -1416,7 +1492,8 @@ void PumpApp::request(QString endpoint, int response_id,
   }
 
 #ifdef DEBUG_NET
-  qDebug() << (method == KQOAuthRequest::GET ? "[GET]" : "[POST]") 
+  qDebug() << (method == KQOAuthRequest::GET  ? "[GET]" :
+               method == KQOAuthRequest::POST ? "[POST]" : "[PUT]") 
            << response_id << ":" << endpoint;
 #endif
 
@@ -1435,7 +1512,7 @@ void PumpApp::request(QString endpoint, int response_id,
     oaRequest->setAdditionalParameters(params);
   }
   
-  if (method == KQOAuthRequest::POST) {
+  if (method == KQOAuthRequest::POST || method == KQOAuthRequest::PUT) {
     QByteArray ba = serializeJson(data);
     oaRequest->setRawData(ba);
     oaRequest->setContentType("application/json");
@@ -1503,7 +1580,7 @@ void PumpApp::onAuthorizedRequestReady(QByteArray response, int rid) {
            << response.count() << "bytes";
 #endif
 #ifdef DEBUG_NET_EVEN_MOAR
-  qDebug() << response;
+  qDebug() << "[DEBUG]" << response;
 #endif
 
   request->deleteLater();
@@ -1556,6 +1633,17 @@ void PumpApp::onAuthorizedRequestReady(QByteArray response, int rid) {
     if (act) { // if not a broken activity
       QASObject* obj = act->object();
 
+      if ((id & QAS_AVATAR_UPLOAD) && obj) {
+
+        QVariantMap jsonImage;
+        jsonImage["url"] = obj->imageUrl();
+        jsonImage["width"] = 96;
+        jsonImage["height"] = 96;
+        m_profile["image"] = jsonImage;
+
+        uploadProfile();
+      }
+
       if ((id & QAS_TOGGLE_LIKE) && obj)
 	obj->toggleLiked();
 
@@ -1578,14 +1666,19 @@ void PumpApp::onAuthorizedRequestReady(QByteArray response, int rid) {
         if (actor)
           followActor(actor);
       }
+
+      if (ol->nextLink().isEmpty())
+        QASActor::setFollowedKnown();
     }
   } else if (sid == QAS_OBJECT) {
     QASObject::getObject(json, this);
   } else if (sid == QAS_ACTORLIST) {
     QASActorList::getActorList(json, this);
-  } else if (sid == QAS_SELF_PROFILE) {
-    m_selfActor = QASActor::getActor(json["profile"].toMap(), this);
+  } else if (sid == QAS_SELF_PROFILE || sid == QAS_EDIT_PROFILE) {
+    m_selfActor = QASActor::getActor(json, this);
     m_selfActor->setYou();
+    if (sid == QAS_EDIT_PROFILE)
+      editProfileDialog();
   } else if (sid == QAS_SELF_LISTS) {
     QASObjectList* lists = QASObjectList::getObjectList(json, this, id);
     for (size_t i=0; i<lists->size(); ++i) {
@@ -1593,9 +1686,9 @@ void PumpApp::onAuthorizedRequestReady(QByteArray response, int rid) {
     }
   } else if (sid == QAS_IMAGE_UPLOAD) {
     m_uploadDialog->reset();
-    updatePostedImage(json);
+    updatePostedImage(json, id & QAS_AVATAR_UPLOAD);
   } else if (sid == QAS_IMAGE_UPDATE) {
-    postImageActivity(json);
+    postImageActivity(json, id & QAS_AVATAR_UPLOAD);
   }
 
   if ((id & QAS_POST) && m_messageWindow && !m_messageWindow->isVisible())
