@@ -11,7 +11,7 @@
     <message>
         <location filename="../src/activitywidget.cpp" line="124"/>
         <source>To:</source>
-        <translation>an:</translation>
+        <translation>An:</translation>
     </message>
     <message>
         <location filename="../src/activitywidget.cpp" line="127"/>
@@ -39,7 +39,7 @@
     <message>
         <location filename="../src/actorwidget.cpp" line="140"/>
         <source>stop minimising posts</source>
-        <translation>Beiträge minimieren ausschalten</translation>
+        <translation>Beiträge nicht mehr minimieren</translation>
     </message>
     <message>
         <location filename="../src/actorwidget.cpp" line="141"/>
@@ -65,42 +65,42 @@
     <message>
         <location filename="../src/editprofiledialog.cpp" line="42"/>
         <source>&amp;Change picture</source>
-        <translation type="unfinished">Bild &amp;ändern</translation>
+        <translation>&amp;Bild ändern</translation>
     </message>
     <message>
         <location filename="../src/editprofiledialog.cpp" line="49"/>
         <source>Real name</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Klarname</translation>
     </message>
     <message>
         <location filename="../src/editprofiledialog.cpp" line="55"/>
         <source>Hometown</source>
-        <translation type="unfinished"></translation>
+        <translation>Heimatstadt</translation>
     </message>
     <message>
         <location filename="../src/editprofiledialog.cpp" line="61"/>
         <source>Bio</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Bio</translation>
     </message>
     <message>
         <location filename="../src/editprofiledialog.cpp" line="138"/>
         <source>Select Image</source>
-        <translation type="unfinished">Bild auswählen</translation>
+        <translation>Bild auswählen</translation>
     </message>
     <message>
         <location filename="../src/editprofiledialog.cpp" line="139"/>
         <source>Image files (*.png *.jpg *.jpeg *.gif);;All files (*.*)</source>
-        <translation type="unfinished">Bilddatei (*.png *.jpg *.jpeg *.gif);;Alle Dateien (*.*)</translation>
+        <translation>Bilddateien (*.png *.jpg *.jpeg *.gif);;Alle Dateien (*.*)</translation>
     </message>
     <message>
         <location filename="../src/editprofiledialog.cpp" line="147"/>
         <source>Sorry!</source>
-        <translation type="unfinished">Entschuldigung!</translation>
+        <translation>Entschuldigung!</translation>
     </message>
     <message>
         <location filename="../src/editprofiledialog.cpp" line="148"/>
         <source>That file didn&apos;t appear to be an image.</source>
-        <translation type="unfinished">Die ausgewählte Datei scheint kein Bild zu sein.</translation>
+        <translation>Die ausgewählte Datei scheint kein Bild zu sein.</translation>
     </message>
 </context>
 <context>
@@ -113,7 +113,7 @@
     <message>
         <location filename="../src/filedownloader.cpp" line="298"/>
         <source>Network error: too many redirections!</source>
-        <translation type="unfinished"></translation>
+        <translation>Netzwerkfehler: Zu viele Weiterleitungen!</translation>
     </message>
     <message>
         <location filename="../src/filedownloader.cpp" line="320"/>
@@ -123,7 +123,7 @@
     <message>
         <location filename="../src/filedownloader.cpp" line="330"/>
         <source>Could not open file %1 for writing: </source>
-        <translation>Datei %1 konnte zum Schreiben nicht geöffnet werden: </translation>
+        <translation>Datei %1 konnte nicht zum Schreiben geöffnet werden: </translation>
     </message>
 </context>
 <context>
@@ -146,7 +146,7 @@
         <location filename="../src/fullobjectwidget.cpp" line="113"/>
         <source>comment</source>
         <comment>Button to comment on a post</comment>
-        <translation type="unfinished">kommentieren</translation>
+        <translation>kommentieren</translation>
     </message>
     <message>
         <location filename="../src/fullobjectwidget.cpp" line="313"/>
@@ -161,12 +161,12 @@
         <location filename="../src/fullobjectwidget.cpp" line="349"/>
         <source>at %1</source>
         <comment>location of person</comment>
-        <translation type="unfinished">@ %1</translation>
+        <translation type="unfinished">in %1</translation>
     </message>
     <message>
         <location filename="../src/fullobjectwidget.cpp" line="351"/>
         <source>Profile last updated %1</source>
-        <translation>letzte Profiländerung am %1</translation>
+        <translation type="unfinished">Profil zuletzt aktualisiert @ %1</translation>
     </message>
     <message>
         <location filename="../src/fullobjectwidget.cpp" line="359"/>
@@ -182,12 +182,12 @@
     <message>
         <location filename="../src/fullobjectwidget.cpp" line="386"/>
         <source>unlike</source>
-        <translation>unlike</translation>
+        <translation type="unfinished">defavorisieren</translation>
     </message>
     <message>
         <location filename="../src/fullobjectwidget.cpp" line="386"/>
         <source>like</source>
-        <translation>like</translation>
+        <translation type="unfinished">favorisieren</translation>
     </message>
     <message>
         <location filename="../src/fullobjectwidget.cpp" line="398"/>
@@ -209,13 +209,13 @@
         <location filename="../src/fullobjectwidget.cpp" line="547"/>
         <source>shared this.</source>
         <comment>Many persons shared</comment>
-        <translation type="unfinished">teilten das.</translation>
+        <translation>teilten das.</translation>
     </message>
     <message>
         <location filename="../src/fullobjectwidget.cpp" line="549"/>
         <source>shared this.</source>
         <comment>One person shared</comment>
-        <translation type="unfinished">teilten das.</translation>
+        <translation>teilte das.</translation>
     </message>
     <message>
         <location filename="../src/fullobjectwidget.cpp" line="629"/>
@@ -226,7 +226,7 @@
         <location filename="../src/fullobjectwidget.cpp" line="673"/>
         <source>post</source>
         <comment>Name of object type.</comment>
-        <translation type="unfinished">Beitrag</translation>
+        <translation>Beitrag</translation>
     </message>
     <message>
         <location filename="../src/fullobjectwidget.cpp" line="676"/>
@@ -238,13 +238,13 @@
         <location filename="../src/fullobjectwidget.cpp" line="678"/>
         <source>comment</source>
         <comment>Name of object type.</comment>
-        <translation type="unfinished">kommentieren</translation>
+        <translation>Kommentar</translation>
     </message>
     <message>
         <location filename="../src/fullobjectwidget.cpp" line="680"/>
         <source>image</source>
         <comment>Name of object type.</comment>
-        <translation type="unfinished">Bild</translation>
+        <translation>Bild</translation>
     </message>
     <message>
         <source>stop following %1</source>
@@ -299,9 +299,9 @@
     <message numerus="yes">
         <location filename="../src/fullobjectwidget.cpp" line="552"/>
         <source>%Ln person(s) shared this.</source>
-        <translation>
-            <numerusform>von %Ln Person geteilt</numerusform>
-            <numerusform>von %Ln Personen geteilt</numerusform>
+        <translation type="unfinished">
+            <numerusform>von %Ln Person geteilt.</numerusform>
+            <numerusform>von %Ln Personen geteilt.</numerusform>
         </translation>
     </message>
     <message>
@@ -323,12 +323,12 @@
     <message>
         <location filename="../src/fullobjectwidget.cpp" line="701"/>
         <source>Are you sure you want to delete this %1?</source>
-        <translation>Sind Sie sicher das sie %1 löschen wollen?</translation>
+        <translation>Sind Sie sicher, dass Sie %1 löschen wollen?</translation>
     </message>
     <message>
         <location filename="../src/fullobjectwidget.cpp" line="721"/>
         <source>Share this %1 by %2?</source>
-        <translation>%1 von %2 teilen?</translation>
+        <translation>Diese(n) %1 von %2 teilen?</translation>
     </message>
     <message>
         <source>Are you sure you want to stop following</source>
@@ -366,7 +366,7 @@
     <message>
         <location filename="../src/messagewindow.cpp" line="91"/>
         <source>To:</source>
-        <translation>To:</translation>
+        <translation>An:</translation>
     </message>
     <message>
         <location filename="../src/messagewindow.cpp" line="92"/>
@@ -381,7 +381,7 @@
     <message>
         <location filename="../src/messagewindow.cpp" line="106"/>
         <source>+ &amp;To</source>
-        <translation>+ &amp;To</translation>
+        <translation>+ &amp;An</translation>
     </message>
     <message>
         <location filename="../src/messagewindow.cpp" line="109"/>
@@ -446,7 +446,7 @@
     <message>
         <location filename="../src/messagewindow.cpp" line="364"/>
         <source>&amp;Update post</source>
-        <translation>Nachricht akt&amp;ualisieren</translation>
+        <translation>Beitrag akt&amp;ualisieren</translation>
     </message>
     <message>
         <location filename="../src/messagewindow.cpp" line="366"/>
@@ -461,7 +461,7 @@
     <message>
         <location filename="../src/messagewindow.cpp" line="518"/>
         <source>Characters: %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Zeichen: %1</translation>
     </message>
     <message>
         <source>Cancel</source>
@@ -478,7 +478,7 @@
     <message>
         <location filename="../src/messagewindow.cpp" line="245"/>
         <source>Select recipient (To)</source>
-        <translation>Empfänger auswählen (To)</translation>
+        <translation>Empfänger auswählen (An)</translation>
     </message>
     <message>
         <location filename="../src/messagewindow.cpp" line="251"/>
@@ -540,13 +540,13 @@
     <message>
         <location filename="../src/oauthwizard.cpp" line="49"/>
         <source>&lt;p&gt;In order to use pump.io you need to first register an account with a pump.io server. If you haven&apos;t done this yet you can do it now by trying out one of the existing public servers: &lt;br /&gt;&lt;a href=&quot;http://pump.io/tryit.html&quot;&gt;http://pump.io/tryit.html&lt;/a&gt;.&lt;/p&gt;&lt;p&gt;When you are done enter your new pump.io account id below in the form of &lt;b&gt;username@servername&lt;/b&gt;.&lt;/p&gt;</source>
-        <translation>&lt;p&gt;Um pump.io nutzen zu können, benötigen Sie einen Account auf einem pump.io-Server. Wenn Sie noch keinen Account besitzen, können Sie sich einfach an einem der öffentlichen pump.io-Server unter folgendem Link registrieren:&lt;/p&gt;
-&lt;a href=&quot;http://pump.io/tryit.html&quot;&gt;http://pump.io/tryit.html&lt;/a&gt;&lt;p&gt;Wenn Sie einen Account erstellt haben oder bereits ein pump.io-Konto besitzen, tragen Sie Ihre Account-ID in dem Format &lt;b&gt;benutzername@servername&lt;/b&gt; in dem unten angezeigten Feld ein.&lt;/p&gt;</translation>
+        <translation>&lt;p&gt;Um pump.io nutzen zu können, benötigen Sie ein Konto auf einem pump.io-Server. Wenn Sie noch kein Konto besitzen, können Sie sich jetzt einfach an einem der öffentlichen pump.io-Server unter folgendem Link registrieren:&lt;/p&gt;
+&lt;a href=&quot;http://pump.io/tryit.html&quot;&gt;http://pump.io/tryit.html&lt;/a&gt;&lt;p&gt;Wenn Sie ein Konto erstellt haben oder bereits ein pump.io-Konto besitzen, tragen Sie Ihre Konto-ID im Format &lt;b&gt;benutzername@servername&lt;/b&gt; unten ein.&lt;/p&gt;</translation>
     </message>
     <message>
         <location filename="../src/oauthwizard.cpp" line="68"/>
         <source>&lt;b&gt;Your pump.io account id:&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Ihre pump.io Account-ID:&lt;/b&gt;</translation>
+        <translation>&lt;b&gt;Ihre pump.io-Konto-ID:&lt;/b&gt;</translation>
     </message>
     <message>
         <location filename="../src/oauthwizard.cpp" line="75"/>
@@ -557,7 +557,7 @@
         <location filename="../src/oauthwizard.cpp" line="85"/>
         <source>Next</source>
         <translatorcomment>&quot;Back&quot; ist leider nicht vorhanden. Daher macht es keinen Sinn nur Next mit Vor zu übersetzen</translatorcomment>
-        <translation></translation>
+        <translation type="unfinished">Weiter</translation>
     </message>
 </context>
 <context>
@@ -570,7 +570,7 @@
     <message>
         <location filename="../src/oauthwizard.cpp" line="135"/>
         <source>In order for Pumpa to be able to read and post new messages to your pump.io account you need to grant Pumpa access via the web page. Pumpa will open the web page for you - just follow the instructions and copy &amp;amp; paste the &lt;b&gt;verifier&lt;/b&gt; text string back into the field below. (The token should be automatically pre-filled.)</source>
-        <translation>Damit Pumpa neue Nachrichten lesen und verfassen kann, müssen Sie den Zugriff auf Ihren pump.io-Account gestatten. Pumpa wird dazu eine Webseite des pump.io-Servers aufrufen, deren Anweisungen Sie folgen. Um den Anmeldevorgang abzuschließen, kopieren Sie den &lt;b&gt;Verifier&lt;/b&gt; in das obere Feld. (Der Token sollte von Pumpa automatisch ausgefüllt werden, sobald sich die Webseite öffenet)</translation>
+        <translation>Damit Pumpa neue Nachrichten lesen und veröffentlichen kann, müssen Sie den Zugriff auf Ihr pump.io-Konto gestatten. Pumpa wird dazu eine Webseite des pump.io-Servers aufrufen, deren Anweisungen Sie folgen. Um den Anmeldevorgang abzuschließen, kopieren Sie den &lt;b&gt;Verifier&lt;/b&gt; in das Feld unten. (Der &quot;Token&quot; sollte von Pumpa automatisch eingetragen werden, sobald sich die Webseite öffnet.)</translation>
     </message>
     <message>
         <location filename="../src/oauthwizard.cpp" line="145"/>
@@ -588,7 +588,7 @@
     <message>
         <location filename="../src/oauthwizard.cpp" line="226"/>
         <source>Registering client ...</source>
-        <translation>Client regestrieren ...</translation>
+        <translation>Registriere Client ...</translation>
     </message>
     <message>
         <location filename="../src/oauthwizard.cpp" line="257"/>
@@ -616,7 +616,7 @@
     <message>
         <location filename="../src/objectwidget.cpp" line="178"/>
         <source>Re: </source>
-        <translation>Re: </translation>
+        <translation>Aw: </translation>
     </message>
     <message>
         <location filename="../src/objectwidget.cpp" line="179"/>
@@ -629,40 +629,40 @@
     <message>
         <location filename="../src/pumpapp.cpp" line="160"/>
         <source>&amp;Inbox</source>
-        <translation>&amp;Nachrichten</translation>
+        <translation type="unfinished">E&amp;ingang</translation>
     </message>
     <message>
         <location filename="../src/pumpapp.cpp" line="161"/>
         <source>&amp;Mentions</source>
-        <translation>&amp;Vorschläge</translation>
+        <translation>&amp;Erwähnungen</translation>
     </message>
     <message>
         <location filename="../src/pumpapp.cpp" line="162"/>
         <source>&amp;Direct</source>
-        <translation>&amp;Posteingang</translation>
+        <translation type="unfinished">&amp;Direkt</translation>
     </message>
     <message>
         <location filename="../src/pumpapp.cpp" line="163"/>
         <source>Mean&amp;while</source>
-        <translation>N&amp;euigkeiten</translation>
+        <translation type="unfinished">Inz&amp;wischen</translation>
     </message>
     <message numerus="yes">
         <location filename="../src/pumpapp.cpp" line="494"/>
         <source>You have %Ln new notification(s).</source>
-        <translation type="unfinished">
-            <numerusform></numerusform>
-            <numerusform></numerusform>
+        <translation>
+            <numerusform>Sie haben %n neue Benachrichtigung.</numerusform>
+            <numerusform>Sie haben %n neue Benachrichtigungen.</numerusform>
         </translation>
     </message>
     <message>
         <location filename="../src/pumpapp.cpp" line="806"/>
         <source>Copyright &amp;copy; 2013-2015 Mats Sj&amp;ouml;berg</source>
-        <translation type="unfinished"></translation>
+        <translation>Copyright &amp;copy; 2013-2015 Mats Sj&amp;ouml;berg</translation>
     </message>
     <message>
         <location filename="../src/pumpapp.cpp" line="1154"/>
         <source>Fi&amp;rehose</source>
-        <translation>Fi&amp;rehose</translation>
+        <translation type="unfinished">Fi&amp;rehose</translation>
     </message>
     <message>
         <location filename="../src/pumpapp.cpp" line="579"/>
@@ -672,7 +672,7 @@
     <message>
         <location filename="../src/pumpapp.cpp" line="638"/>
         <source>%1 &amp;Window</source>
-        <translation>%1 Fenster</translation>
+        <translation>%1 &amp;Fenster</translation>
     </message>
     <message>
         <location filename="../src/pumpapp.cpp" line="638"/>
@@ -687,17 +687,17 @@
     <message>
         <location filename="../src/pumpapp.cpp" line="653"/>
         <source>E&amp;xit</source>
-        <translation>E&amp;xit</translation>
+        <translation type="unfinished">&amp;Verlassen</translation>
     </message>
     <message>
         <location filename="../src/pumpapp.cpp" line="654"/>
         <source>Ctrl+Q</source>
-        <translation>Strg+X</translation>
+        <translation>Strg+Q</translation>
     </message>
     <message>
         <location filename="../src/pumpapp.cpp" line="657"/>
         <source>Preferences</source>
-        <translation>Eigenschaften</translation>
+        <translation>Einstellungen</translation>
     </message>
     <message>
         <location filename="../src/pumpapp.cpp" line="660"/>
@@ -707,7 +707,7 @@
     <message>
         <location filename="../src/pumpapp.cpp" line="661"/>
         <source>Ctrl+R</source>
-        <translation>Strg+R</translation>
+        <translation type="unfinished">Strg+R</translation>
     </message>
     <message>
         <location filename="../src/pumpapp.cpp" line="665"/>
@@ -717,22 +717,22 @@
     <message>
         <location filename="../src/pumpapp.cpp" line="666"/>
         <source>Ctrl+O</source>
-        <translation>Strg+L</translation>
+        <translation type="unfinished">Strg+L</translation>
     </message>
     <message>
         <location filename="../src/pumpapp.cpp" line="669"/>
         <source>F&amp;ollow an account</source>
-        <translation>Nutzer &amp;folgen</translation>
+        <translation>Nutzer f&amp;olgen</translation>
     </message>
     <message>
         <location filename="../src/pumpapp.cpp" line="670"/>
         <source>Ctrl+L</source>
-        <translation>Strg+F</translation>
+        <translation type="unfinished">Strg+F</translation>
     </message>
     <message>
         <location filename="../src/pumpapp.cpp" line="676"/>
         <source>&amp;About</source>
-        <translation>Über</translation>
+        <translation>&amp;Über</translation>
     </message>
     <message>
         <location filename="../src/pumpapp.cpp" line="679"/>
@@ -758,12 +758,12 @@
         <location filename="../src/pumpapp.cpp" line="314"/>
         <location filename="../src/pumpapp.cpp" line="702"/>
         <source>Followers</source>
-        <translation>Followers</translation>
+        <translation type="unfinished">Verfolger</translation>
     </message>
     <message>
         <location filename="../src/pumpapp.cpp" line="250"/>
         <source>SSL Error: </source>
-        <translation>SSL Fehler: </translation>
+        <translation>SSL-Fehler: </translation>
     </message>
     <message>
         <location filename="../src/pumpapp.cpp" line="253"/>
@@ -777,7 +777,7 @@
         <location filename="../src/pumpapp.cpp" line="261"/>
         <source>SSL Server certificate.
 </source>
-        <translation>SSL Server Zertifkat.</translation>
+        <translation>SSL-Server-Zertifkat.</translation>
     </message>
     <message>
         <location filename="../src/pumpapp.cpp" line="262"/>
@@ -792,17 +792,17 @@
     <message>
         <location filename="../src/pumpapp.cpp" line="264"/>
         <source>Effective: </source>
-        <translation>Effektiv: </translation>
+        <translation type="unfinished">Wirksam: </translation>
     </message>
     <message>
         <location filename="../src/pumpapp.cpp" line="265"/>
         <source>Expires: </source>
-        <translation>Gültig bis: </translation>
+        <translation type="unfinished">Verfällt: </translation>
     </message>
     <message>
         <location filename="../src/pumpapp.cpp" line="266"/>
         <source>MD5 digest: </source>
-        <translation>MD5-Digest: </translation>
+        <translation>MD5-Hashwert: </translation>
     </message>
     <message>
         <location filename="../src/pumpapp.cpp" line="273"/>
@@ -826,27 +826,27 @@
     <message>
         <location filename="../src/pumpapp.cpp" line="506"/>
         <source>%1 wrote: </source>
-        <translation>%1 schreibt: </translation>
+        <translation>%1 schrieb: </translation>
     </message>
     <message>
         <location filename="../src/pumpapp.cpp" line="673"/>
         <source>Your &amp;profile</source>
-        <translation type="unfinished"></translation>
+        <translation>Ihr &amp;Profil</translation>
     </message>
     <message>
         <location filename="../src/pumpapp.cpp" line="682"/>
         <source>Report &amp;bug online</source>
-        <translation type="unfinished"></translation>
+        <translation>Programm&amp;fehler online melden</translation>
     </message>
     <message>
         <location filename="../src/pumpapp.cpp" line="694"/>
         <source>Close tab</source>
-        <translation type="unfinished"></translation>
+        <translation>Reiter schließen</translation>
     </message>
     <message>
         <location filename="../src/pumpapp.cpp" line="695"/>
         <source>Ctrl+W</source>
-        <translation></translation>
+        <translation>Strg+W</translation>
     </message>
     <message>
         <location filename="../src/pumpapp.cpp" line="699"/>
@@ -856,7 +856,7 @@
     <message>
         <location filename="../src/pumpapp.cpp" line="705"/>
         <source>Following</source>
-        <translation></translation>
+        <translation type="unfinished">Verfolgte</translation>
     </message>
     <message>
         <location filename="../src/pumpapp.cpp" line="708"/>
@@ -871,12 +871,12 @@
     <message>
         <location filename="../src/pumpapp.cpp" line="723"/>
         <source>&amp;Pumpa</source>
-        <translation></translation>
+        <translation>&amp;Pumpa</translation>
     </message>
     <message>
         <location filename="../src/pumpapp.cpp" line="736"/>
         <source>&amp;Tabs</source>
-        <translation></translation>
+        <translation>&amp;Reiter</translation>
     </message>
     <message>
         <location filename="../src/pumpapp.cpp" line="745"/>
@@ -886,12 +886,12 @@
     <message>
         <location filename="../src/pumpapp.cpp" line="777"/>
         <source>&lt;p&gt;Pumpa is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.&lt;/p&gt;&lt;p&gt;Pumpa is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.&lt;/p&gt;&lt;p&gt;You should have received a copy of the GNU General Public License along with Pumpa.  If not, see &lt;a href=&quot;http://www.gnu.org/licenses/&quot;&gt;http://www.gnu.org/licenses/&lt;/a&gt;.&lt;/p&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;p&gt;Pumpa ist freie Software: Sie können es weiterverbreiten und/oder verändern unter den Bedingungen der &apos;GNU General Public License&apos;, wie sie von der &apos;Free Software Foundation&apos; in Version 3 oder (nach ihrer Wahl) einer späteren Version veröffentlicht wurde.&lt;/p&gt;&lt;p&gt;Pumpa wird in der Hoffnung verbreitet, dass es nützlich sei, jedoch OHNE JEGLICHE GEWÄHRLEISTUNG; auch ohne eine inbegriffene MARKTGÄNGIKEIT oder EIGNUNG FÜR EINEN BESTIMMTEN ZWECK. Wenden Sie sich an die&apos;GNU General Public License&apos; für weitere Details.&lt;/p&gt;&lt;p&gt;Sie sollten eine Kopie der &apos;GNU General Public License&apos; zusamment mit Pumpa erhalten haben. Andernfalls, schauen Sie auf &lt;a href=&quot;http://www.gnu.org/licenses/&quot;&gt;http://www.gnu.org/licenses/&lt;/a&gt;.&lt;/p&gt;</translation>
     </message>
     <message>
         <location filename="../src/pumpapp.cpp" line="790"/>
         <source>&lt;p&gt;The &lt;a href=&quot;https://github.com/kypeli/kQOAuth&quot;&gt;kQOAuth library&lt;/a&gt; is copyrighted by &lt;a href=&quot;http://www.johanpaul.com/&quot;&gt;Johan Paul&lt;/a&gt; and licensed under LGPL 2.1.&lt;/p&gt;&lt;p&gt;The &lt;a href=&quot;https://github.com/vmg/sundown&quot;&gt;sundown Markdown library&lt;/a&gt; is copyrighted by Natacha Port&amp;eacute;, Vicent Marti and others, and &lt;a href=&quot;https://github.com/vmg/sundown#license&quot;&gt;permissively licensed&lt;/a&gt;.&lt;/p&gt;&lt;p&gt;The Pumpa logo was &lt;a href=&quot;http://opengameart.org/content/fruit-and-veggie-inventory&quot;&gt;created by Joshua Taylor&lt;/a&gt; for the &lt;a href=&quot;http://lpc.opengameart.org/&quot;&gt;Liberated Pixel Cup&lt;/a&gt;.The logo is copyrighted by the artist and is dual licensed under the CC-BY-SA 3.0 license and the GNU GPL 3.0.</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;p&gt;Die&lt;a href=&quot;https://github.com/kypeli/kQOAuth&quot;&gt;kQOAuth-Bibliothek&lt;/a&gt; hat das Copyright von &lt;a href=&quot;http://www.johanpaul.com/&quot;&gt;Johan Paul&lt;/a&gt; und ist unter LGPL 2.1 lizensiert.&lt;/p&gt;&lt;p&gt;Die &lt;a href=&quot;https://github.com/vmg/sundown&quot;&gt;sundown-Markdown-Bibliothek&lt;/a&gt; hat das Copyright von Natacha Port&amp;eacute;, Vicent Marti und anderen, und ist &lt;a href=&quot;https://github.com/vmg/sundown#license&quot;&gt;großzügig lizensiert&lt;/a&gt;.&lt;/p&gt;&lt;p&gt;Das Pumpa-Logo wurde &lt;a href=&quot;http://opengameart.org/content/fruit-and-veggie-inventory&quot;&gt;von Joshua Taylor entworfen&lt;/a&gt; für den &lt;a href=&quot;http://lpc.opengameart.org/&quot;&gt;Liberated-Pixel-Cup&lt;/a&gt;.Das Logo hat das Copyright des Künstlers und ist dopppelt unter der CC-BY-SA 3.0-Lizenz und der GNU GPL 3.0 lizensiert.</translation>
     </message>
     <message>
         <location filename="../src/pumpapp.cpp" line="809"/>
@@ -911,7 +911,7 @@
     <message>
         <location filename="../src/pumpapp.cpp" line="934"/>
         <source>Site not configured yet!</source>
-        <translation>Seite ist nicht konfiguriert!</translation>
+        <translation>Seite ist noch nicht konfiguriert!</translation>
     </message>
     <message>
         <location filename="../src/pumpapp.cpp" line="984"/>
@@ -926,12 +926,12 @@
     <message>
         <location filename="../src/pumpapp.cpp" line="995"/>
         <source>Sorry, that doesn&apos;t even look like a webfinger ID!</source>
-        <translation>Entschuldigung, aber das sieht leider nicht nach einer Webfinger-ID aus!</translation>
+        <translation>Entschuldigung, aber das sieht leider nicht wie eine Webfinger-ID aus!</translation>
     </message>
     <message>
         <location filename="../src/pumpapp.cpp" line="1000"/>
         <source>Sorry, you are already following that person!</source>
-        <translation>Entschuldigung! Sie folgen dieser Person bereits!</translation>
+        <translation>Entschuldigung, Sie folgen dieser Person bereits!</translation>
     </message>
     <message>
         <location filename="../src/pumpapp.cpp" line="1098"/>
@@ -946,27 +946,27 @@
     <message>
         <location filename="../src/pumpapp.cpp" line="1130"/>
         <source>&amp;Context</source>
-        <translation>Kontext</translation>
+        <translation>&amp;Kontext</translation>
     </message>
     <message>
         <location filename="../src/pumpapp.cpp" line="1163"/>
         <source>&amp;Followers</source>
-        <translation></translation>
+        <translation>Ver&amp;folger</translation>
     </message>
     <message>
         <location filename="../src/pumpapp.cpp" line="1172"/>
         <source>F&amp;ollowing</source>
-        <translation></translation>
+        <translation>F&amp;olge</translation>
     </message>
     <message>
         <location filename="../src/pumpapp.cpp" line="1181"/>
         <source>F&amp;avorites</source>
-        <translation>F&amp;avoriten</translation>
+        <translation>Fa&amp;voriten</translation>
     </message>
     <message>
         <location filename="../src/pumpapp.cpp" line="1190"/>
         <source>A&amp;ctivities</source>
-        <translation>Aktivitäten</translation>
+        <translation>&amp;Aktivitäten</translation>
     </message>
     <message>
         <location filename="../src/pumpapp.cpp" line="1528"/>
@@ -976,7 +976,7 @@
     <message>
         <location filename="../src/pumpapp.cpp" line="1590"/>
         <source>Ready!</source>
-        <translation>Fertig!</translation>
+        <translation>Bereit!</translation>
     </message>
     <message>
         <location filename="../src/pumpapp.cpp" line="1608"/>
@@ -1019,17 +1019,17 @@
     <message>
         <location filename="../src/pumpasettingsdialog.cpp" line="40"/>
         <source>Change account</source>
-        <translation>Konto ändern</translation>
+        <translation>Konto wechseln</translation>
     </message>
     <message>
         <location filename="../src/pumpasettingsdialog.cpp" line="45"/>
         <source>Clicking &quot;Change account&quot; will run the authentication setup again for a new pump.io account. This will remove the current login credentials since Pumpa only supports one account at a time.</source>
-        <translation>Wenn sie auf &quot;Konto ändern&quot; klicken, wird der Authentifizierungsprozess neu gestartet. Alle Anmeldedaten zu Ihrem pump.io-Account werden vom System entfernt. Mit Pumpa kann zur Zeit nur ein Account zur selben Zeit genutzt werden.</translation>
+        <translation>Wenn sie auf &quot;Konto wechseln&quot; klicken, wird der Authentifizierungsprozess neu gestartet. Alle Anmeldedaten zu Ihrem pump.io-Konto werden vom System entfernt. Mit Pumpa können zur Zeit nicht mehrere Konten gleichzeitig genutzt werden.</translation>
     </message>
     <message>
         <location filename="../src/pumpasettingsdialog.cpp" line="56"/>
         <source>Interface</source>
-        <translation>Schnittstelle</translation>
+        <translation>Benutzeroberfläche</translation>
     </message>
     <message>
         <location filename="../src/pumpasettingsdialog.cpp" line="63"/>
@@ -1044,12 +1044,12 @@
     <message>
         <location filename="../src/pumpasettingsdialog.cpp" line="69"/>
         <source>Followers</source>
-        <translation></translation>
+        <translation type="unfinished">Verfolger</translation>
     </message>
     <message>
         <location filename="../src/pumpasettingsdialog.cpp" line="73"/>
         <source>Default &quot;To&quot;:</source>
-        <translation>Standardempfänger für &quot;To&quot;:</translation>
+        <translation>Standardempfänger für &quot;An&quot;:</translation>
     </message>
     <message>
         <location filename="../src/pumpasettingsdialog.cpp" line="77"/>
@@ -1064,7 +1064,7 @@
     <message>
         <location filename="../src/pumpasettingsdialog.cpp" line="82"/>
         <source>Show message character count</source>
-        <translation type="unfinished"></translation>
+        <translation>Zeige Zeichenanzahl von Nachrichten an</translation>
     </message>
     <message>
         <location filename="../src/pumpasettingsdialog.cpp" line="88"/>
@@ -1084,12 +1084,12 @@
     <message>
         <location filename="../src/pumpasettingsdialog.cpp" line="94"/>
         <source>Direct or mention</source>
-        <translation>Direkt oder mit Vorschlägen</translation>
+        <translation>Direkt oder Erwähnung</translation>
     </message>
     <message>
         <location filename="../src/pumpasettingsdialog.cpp" line="95"/>
         <source>Direct, mention or inbox</source>
-        <translation>Direkt, mit Vorschlägen oder aus dem Posteingang</translation>
+        <translation>Direkt, Erwähnung oder aus dem Eingang</translation>
     </message>
     <message>
         <location filename="../src/pumpasettingsdialog.cpp" line="96"/>
