@@ -9,17 +9,17 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/activitywidget.cpp" line="121"/>
+        <location filename="../src/activitywidget.cpp" line="124"/>
         <source>To:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/activitywidget.cpp" line="124"/>
+        <location filename="../src/activitywidget.cpp" line="127"/>
         <source>CC:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/activitywidget.cpp" line="141"/>
+        <location filename="../src/activitywidget.cpp" line="144"/>
         <source>Public</source>
         <translation type="unfinished"></translation>
     </message>
@@ -60,6 +60,49 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>EditProfileDialog</name>
+    <message>
+        <location filename="../src/editprofiledialog.cpp" line="42"/>
+        <source>&amp;Change picture</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/editprofiledialog.cpp" line="49"/>
+        <source>Real name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/editprofiledialog.cpp" line="55"/>
+        <source>Hometown</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/editprofiledialog.cpp" line="61"/>
+        <source>Bio</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/editprofiledialog.cpp" line="138"/>
+        <source>Select Image</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/editprofiledialog.cpp" line="139"/>
+        <source>Image files (*.png *.jpg *.jpeg *.gif);;All files (*.*)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/editprofiledialog.cpp" line="147"/>
+        <source>Sorry!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/editprofiledialog.cpp" line="148"/>
+        <source>That file didn&apos;t appear to be an image.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>FileDownloader</name>
     <message>
@@ -97,8 +140,8 @@
     </message>
     <message>
         <location filename="../src/fullobjectwidget.cpp" line="113"/>
-        <location filename="../src/fullobjectwidget.cpp" line="673"/>
         <source>comment</source>
+        <comment>Button to comment on a post</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -108,8 +151,8 @@
     </message>
     <message>
         <location filename="../src/fullobjectwidget.cpp" line="349"/>
-        <location filename="../src/fullobjectwidget.cpp" line="366"/>
         <source>at %1</source>
+        <comment>location of person</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -122,6 +165,12 @@
         <source>updated %1</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../src/fullobjectwidget.cpp" line="366"/>
+        <source>at %1</source>
+        <comment>time when post was published</comment>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../src/fullobjectwidget.cpp" line="386"/>
         <source>unlike</source>
@@ -148,27 +197,27 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/fullobjectwidget.cpp" line="440"/>
+        <location filename="../src/fullobjectwidget.cpp" line="442"/>
         <source>follow %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/fullobjectwidget.cpp" line="510"/>
+        <location filename="../src/fullobjectwidget.cpp" line="512"/>
         <source>You like this.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/fullobjectwidget.cpp" line="512"/>
+        <location filename="../src/fullobjectwidget.cpp" line="514"/>
         <source>%1 likes this.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/fullobjectwidget.cpp" line="514"/>
+        <location filename="../src/fullobjectwidget.cpp" line="516"/>
         <source>%1 like this.</source>
         <translation type="unfinished"></translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/fullobjectwidget.cpp" line="543"/>
+        <location filename="../src/fullobjectwidget.cpp" line="545"/>
         <source>and %Ln other person(s)</source>
         <translation>
             <numerusform>and one other person</numerusform>
@@ -176,10 +225,46 @@
         </translation>
     </message>
     <message>
-        <location filename="../src/fullobjectwidget.cpp" line="624"/>
+        <location filename="../src/fullobjectwidget.cpp" line="547"/>
+        <source>shared this.</source>
+        <comment>Many persons shared</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/fullobjectwidget.cpp" line="549"/>
+        <source>shared this.</source>
+        <comment>One person shared</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/fullobjectwidget.cpp" line="629"/>
         <source>Show all replies</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../src/fullobjectwidget.cpp" line="673"/>
+        <source>post</source>
+        <comment>Name of object type.</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/fullobjectwidget.cpp" line="676"/>
+        <source>note</source>
+        <comment>Name of object type.</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/fullobjectwidget.cpp" line="678"/>
+        <source>comment</source>
+        <comment>Name of object type.</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/fullobjectwidget.cpp" line="680"/>
+        <source>image</source>
+        <comment>Name of object type.</comment>
+        <translation type="unfinished"></translation>
+    </message>
     <message numerus="yes">
         <source>%Ln persons shared this.</source>
         <translation type="obsolete">
@@ -187,13 +272,8 @@
             <numerusform>%n persons shared this.</numerusform>
         </translation>
     </message>
-    <message>
-        <location filename="../src/fullobjectwidget.cpp" line="544"/>
-        <source>shared this.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message numerus="yes">
-        <location filename="../src/fullobjectwidget.cpp" line="547"/>
+        <location filename="../src/fullobjectwidget.cpp" line="552"/>
         <source>%Ln person(s) shared this.</source>
         <translation type="unfinished">
             <numerusform></numerusform>
@@ -201,27 +281,12 @@
         </translation>
     </message>
     <message>
-        <location filename="../src/fullobjectwidget.cpp" line="668"/>
-        <source>post</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/fullobjectwidget.cpp" line="671"/>
-        <source>note</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/fullobjectwidget.cpp" line="675"/>
-        <source>image</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/fullobjectwidget.cpp" line="696"/>
+        <location filename="../src/fullobjectwidget.cpp" line="701"/>
         <source>Are you sure you want to delete this %1?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/fullobjectwidget.cpp" line="716"/>
+        <location filename="../src/fullobjectwidget.cpp" line="721"/>
         <source>Share this %1 by %2?</source>
         <translation type="unfinished"></translation>
     </message>
@@ -500,186 +565,186 @@
 <context>
     <name>PumpApp</name>
     <message>
-        <location filename="../src/pumpapp.cpp" line="158"/>
+        <location filename="../src/pumpapp.cpp" line="160"/>
         <source>&amp;Inbox</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="159"/>
+        <location filename="../src/pumpapp.cpp" line="161"/>
         <source>&amp;Mentions</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="160"/>
+        <location filename="../src/pumpapp.cpp" line="162"/>
         <source>&amp;Direct</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="161"/>
+        <location filename="../src/pumpapp.cpp" line="163"/>
         <source>Mean&amp;while</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="804"/>
+        <location filename="../src/pumpapp.cpp" line="806"/>
         <source>Copyright &amp;copy; 2013-2015 Mats Sj&amp;ouml;berg</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="1096"/>
+        <location filename="../src/pumpapp.cpp" line="1154"/>
         <source>Fi&amp;rehose</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="581"/>
+        <location filename="../src/pumpapp.cpp" line="579"/>
         <source>Error: </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="640"/>
+        <location filename="../src/pumpapp.cpp" line="638"/>
         <source>%1 &amp;Window</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="640"/>
+        <location filename="../src/pumpapp.cpp" line="638"/>
         <source>Hide</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="640"/>
+        <location filename="../src/pumpapp.cpp" line="638"/>
         <source>Show</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="655"/>
+        <location filename="../src/pumpapp.cpp" line="653"/>
         <source>E&amp;xit</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="656"/>
+        <location filename="../src/pumpapp.cpp" line="654"/>
         <source>Ctrl+Q</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="659"/>
+        <location filename="../src/pumpapp.cpp" line="657"/>
         <source>Preferences</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="662"/>
+        <location filename="../src/pumpapp.cpp" line="660"/>
         <source>&amp;Reload timeline</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="663"/>
+        <location filename="../src/pumpapp.cpp" line="661"/>
         <source>Ctrl+R</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="667"/>
+        <location filename="../src/pumpapp.cpp" line="665"/>
         <source>Load older in timeline</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="668"/>
+        <location filename="../src/pumpapp.cpp" line="666"/>
         <source>Ctrl+O</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="671"/>
+        <location filename="../src/pumpapp.cpp" line="669"/>
         <source>F&amp;ollow an account</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="672"/>
+        <location filename="../src/pumpapp.cpp" line="670"/>
         <source>Ctrl+L</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="675"/>
+        <location filename="../src/pumpapp.cpp" line="676"/>
         <source>&amp;About</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="678"/>
+        <location filename="../src/pumpapp.cpp" line="679"/>
         <source>About &amp;Qt</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="684"/>
+        <location filename="../src/pumpapp.cpp" line="685"/>
         <source>New &amp;Note</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="685"/>
+        <location filename="../src/pumpapp.cpp" line="686"/>
         <source>Ctrl+N</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="689"/>
+        <location filename="../src/pumpapp.cpp" line="690"/>
         <source>Ctrl+D</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="316"/>
-        <location filename="../src/pumpapp.cpp" line="701"/>
+        <location filename="../src/pumpapp.cpp" line="314"/>
+        <location filename="../src/pumpapp.cpp" line="702"/>
         <source>Followers</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="248"/>
+        <location filename="../src/pumpapp.cpp" line="250"/>
         <source>SSL Error: </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="251"/>
+        <location filename="../src/pumpapp.cpp" line="253"/>
         <source>
 %1 is unable to verify the identity of the server. This error could mean that someone is trying to impersonate the server, or that the server&apos;s administrator has made an error.
 </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="259"/>
+        <location filename="../src/pumpapp.cpp" line="261"/>
         <source>SSL Server certificate.
 </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="260"/>
+        <location filename="../src/pumpapp.cpp" line="262"/>
         <source>Issued to: </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="261"/>
+        <location filename="../src/pumpapp.cpp" line="263"/>
         <source>Issued by: </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="262"/>
+        <location filename="../src/pumpapp.cpp" line="264"/>
         <source>Effective: </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="263"/>
+        <location filename="../src/pumpapp.cpp" line="265"/>
         <source>Expires: </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="264"/>
+        <location filename="../src/pumpapp.cpp" line="266"/>
         <source>MD5 digest: </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="271"/>
+        <location filename="../src/pumpapp.cpp" line="273"/>
         <source>&lt;b&gt;Untrusted SSL connection!&lt;/b&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="310"/>
+        <location filename="../src/pumpapp.cpp" line="831"/>
         <source>Public</source>
         <translation type="unfinished"></translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/pumpapp.cpp" line="496"/>
+        <location filename="../src/pumpapp.cpp" line="494"/>
         <source>You have %Ln new notification(s).</source>
         <translation type="unfinished">
             <numerusform></numerusform>
@@ -687,177 +752,187 @@
         </translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="506"/>
+        <location filename="../src/pumpapp.cpp" line="504"/>
         <source>%1 commented: </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="508"/>
+        <location filename="../src/pumpapp.cpp" line="506"/>
         <source>%1 wrote: </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="681"/>
+        <location filename="../src/pumpapp.cpp" line="673"/>
+        <source>Your &amp;profile</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/pumpapp.cpp" line="682"/>
         <source>Report &amp;bug online</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../src/pumpapp.cpp" line="694"/>
+        <source>Close tab</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/pumpapp.cpp" line="695"/>
         <source>Ctrl+W</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="698"/>
+        <location filename="../src/pumpapp.cpp" line="699"/>
         <source>Firehose</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="704"/>
+        <location filename="../src/pumpapp.cpp" line="705"/>
         <source>Following</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="707"/>
+        <location filename="../src/pumpapp.cpp" line="708"/>
         <source>Favorites</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="711"/>
+        <location filename="../src/pumpapp.cpp" line="712"/>
         <source>Activities</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="722"/>
+        <location filename="../src/pumpapp.cpp" line="723"/>
         <source>&amp;Pumpa</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="734"/>
+        <location filename="../src/pumpapp.cpp" line="736"/>
         <source>&amp;Tabs</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="743"/>
+        <location filename="../src/pumpapp.cpp" line="745"/>
         <source>&amp;Help</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="775"/>
+        <location filename="../src/pumpapp.cpp" line="777"/>
         <source>&lt;p&gt;Pumpa is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.&lt;/p&gt;&lt;p&gt;Pumpa is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.&lt;/p&gt;&lt;p&gt;You should have received a copy of the GNU General Public License along with Pumpa.  If not, see &lt;a href=&quot;http://www.gnu.org/licenses/&quot;&gt;http://www.gnu.org/licenses/&lt;/a&gt;.&lt;/p&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="788"/>
+        <location filename="../src/pumpapp.cpp" line="790"/>
         <source>&lt;p&gt;The &lt;a href=&quot;https://github.com/kypeli/kQOAuth&quot;&gt;kQOAuth library&lt;/a&gt; is copyrighted by &lt;a href=&quot;http://www.johanpaul.com/&quot;&gt;Johan Paul&lt;/a&gt; and licensed under LGPL 2.1.&lt;/p&gt;&lt;p&gt;The &lt;a href=&quot;https://github.com/vmg/sundown&quot;&gt;sundown Markdown library&lt;/a&gt; is copyrighted by Natacha Port&amp;eacute;, Vicent Marti and others, and &lt;a href=&quot;https://github.com/vmg/sundown#license&quot;&gt;permissively licensed&lt;/a&gt;.&lt;/p&gt;&lt;p&gt;The Pumpa logo was &lt;a href=&quot;http://opengameart.org/content/fruit-and-veggie-inventory&quot;&gt;created by Joshua Taylor&lt;/a&gt; for the &lt;a href=&quot;http://lpc.opengameart.org/&quot;&gt;Liberated Pixel Cup&lt;/a&gt;.The logo is copyrighted by the artist and is dual licensed under the CC-BY-SA 3.0 license and the GNU GPL 3.0.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="807"/>
+        <location filename="../src/pumpapp.cpp" line="809"/>
         <source>&lt;p&gt;Report bugs and feature requests at &lt;a href=&quot;%5&quot;&gt;%5&lt;/a&gt;.&lt;/p&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="811"/>
+        <location filename="../src/pumpapp.cpp" line="813"/>
         <source>A simple Qt-based pump.io client.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="815"/>
+        <location filename="../src/pumpapp.cpp" line="817"/>
         <source>About %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="922"/>
+        <location filename="../src/pumpapp.cpp" line="934"/>
         <source>Site not configured yet!</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="972"/>
+        <location filename="../src/pumpapp.cpp" line="984"/>
         <source>Follow pump.io user</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="973"/>
+        <location filename="../src/pumpapp.cpp" line="985"/>
         <source>Enter webfinger ID of person to follow: </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="983"/>
+        <location filename="../src/pumpapp.cpp" line="995"/>
         <source>Sorry, that doesn&apos;t even look like a webfinger ID!</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="988"/>
+        <location filename="../src/pumpapp.cpp" line="1000"/>
         <source>Sorry, you are already following that person!</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="1040"/>
+        <location filename="../src/pumpapp.cpp" line="1098"/>
         <source>Invalid user: </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="1047"/>
+        <location filename="../src/pumpapp.cpp" line="1105"/>
         <source>Invalid user (cannot check site): </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="1072"/>
+        <location filename="../src/pumpapp.cpp" line="1130"/>
         <source>&amp;Context</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="1105"/>
+        <location filename="../src/pumpapp.cpp" line="1163"/>
         <source>&amp;Followers</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="1114"/>
+        <location filename="../src/pumpapp.cpp" line="1172"/>
         <source>F&amp;ollowing</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="1123"/>
+        <location filename="../src/pumpapp.cpp" line="1181"/>
         <source>F&amp;avorites</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="1132"/>
+        <location filename="../src/pumpapp.cpp" line="1190"/>
         <source>A&amp;ctivities</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="1451"/>
+        <location filename="../src/pumpapp.cpp" line="1528"/>
         <source>Loading ...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="1513"/>
+        <location filename="../src/pumpapp.cpp" line="1590"/>
         <source>Ready!</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="1531"/>
+        <location filename="../src/pumpapp.cpp" line="1608"/>
         <source>Unable to post message!</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="1535"/>
+        <location filename="../src/pumpapp.cpp" line="1612"/>
         <source>Unable to upload image!</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="1539"/>
+        <location filename="../src/pumpapp.cpp" line="1616"/>
         <source>Network or authorisation error [%1/%2] %3.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="1567"/>
+        <location filename="../src/pumpapp.cpp" line="1655"/>
         <source>Successfully followed </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/pumpapp.cpp" line="1568"/>
+        <location filename="../src/pumpapp.cpp" line="1656"/>
         <source>Successfully unfollowed </source>
         <translation type="unfinished"></translation>
     </message>
